<?php

namespace App\Gateway;

use App\Connexion;
use App\Data\Account;
use PDO;

class AccountGateway {
    private Connexion $con;

    /**
     * @param Connexion $con
     */
    public function __construct(Connexion $con) {
        $this->con = $con;
    }


    public function exists(string $email): bool {
        return $this->getAccount($email) != null;
    }


    public function insertAccount(Account $account, string $hash): void {
        $this->con->exec("INSERT INTO Account VALUES (:username,:hash,:email)", [
            ':username' => [$account->getName(), PDO::PARAM_STR],
            ':hash' => [$hash, PDO::PARAM_STR],
            ':email' => [$account->getEmail(), PDO::PARAM_STR],
            ':token' => [$account->getToken(), PDO::PARAM_STR]
        ]);
    }

    public function getHash(string $email): string {
        $results = $this->con->fetch("SELECT hash FROM Account WHERE email = :email", [
            ':email' => [$email, PDO::PARAM_STR]
        ]);
        return $results[0]['hash'];
    }


    /**
     * @param string $email
     * @return Account|null
     */
    public function getAccount(string $email): ?Account {
        $results = $this->con->fetch("SELECT username,email,token FROM Account WHERE email = :email", [':email' => [$email, PDO::PARAM_STR]]);
        if (empty($results))
            return null;

        $acc = $results[0];
        return new Account($acc["email"], $acc["name"], $acc["token"]);
    }


}
